<?php
/**
 * @package WordPress
 * @subpackage Toolbox
 */

/**
 * Make theme available for translation
 * Translations can be filed in the /languages/ directory
 * If you're building a theme based on toolbox, use a find and replace
 * to change 'toolbox' to the name of your theme in all the template files
 */
load_theme_textdomain( 'toolbox', TEMPLATEPATH . '/languages' );
$locale = get_locale();
$locale_file = TEMPLATEPATH . "/languages/$locale.php";
if ( is_readable( $locale_file ) )
	require_once( $locale_file );
	
/**
 * This theme uses wp_nav_menu() in one location.
 */
register_nav_menus( array(
	'primary' => __( 'Primary Menu', 'toolbox' ),
) );
	
// Set the excerpt length here
add_filter('excerpt_length', 'toolbox_excerpt_length');
function toolbox_excerpt_length($length) {
	return 50; }

// Set the content width based on the theme's design and stylesheet.

if ( ! isset( $content_width ) )
	$content_width = 640; /* pixels */

// excerpt continue reading...
function excerpt_toolbox($text) {
   return str_replace('[...]', ' <a href="'.get_permalink().'"> Read more...</a>', $text); }
add_filter('the_excerpt', 'excerpt_toolbox');

// This sets the dimensions for the thumbnails displayed on the homepage
	add_theme_support( 'post-thumbnails' );
    add_image_size('excerpt-thumbnail', 140, 140, true);
	

// Add default posts and comments RSS feed links to head

add_theme_support( 'automatic-feed-links' );


// Add support for the Aside and Gallery Post Formats

add_theme_support( 'post-formats', array( 'aside', 'gallery' ) );


// Register widgetized area and update sidebar with default widgets

function toolbox_widgets_init() {
	register_sidebar( array (
		'name' => __( 'Sidebar 1', 'toolbox' ),
		'id' => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1>',
	) );

	register_sidebar( array (
		'name' => __( 'Sidebar 2', 'toolbox' ),
		'id' => 'sidebar-2',
		'description' => __( 'An optional second sidebar area', 'toolbox' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1>',
	) );	
}
add_action( 'init', 'toolbox_widgets_init' );
add_theme_support( 'automatic-feed-links' );

$themename = "Basic Press";
$shortname = "toolbox";
$version = "1.0";

$options = array (
	'header' => array (
		'name' => __('Main Options', 'toolbox'),
		'type' => 'section'
	),

	'show_menu' => array(
		'name' => __('Show Menu under header?', 'toolbox'),
		'desc' => '',
		'type' => 'checkbox',
		'default' => 'off',
		'category' => 'posts'
	),
	
	'show_tag' => array(
		'name' => __('Show post tags?', 'toolbox'),
		'desc' => '',
		'type' => 'checkbox',
		'default' => 'off',
		'category' => 'posts'
	),
	'show_cat' => array(
		'name' => __('Show Categories?', 'toolbox'),
		'desc' => '',
		'type' => 'checkbox',
		'default' => 'off',
		'category' => 'posts'
	),
		'show_thumb' => array(
		'name' => __('Show Post Thumbnails?', 'toolbox'),
		'desc' => '',
		'type' => 'checkbox',
		'default' => 'on',
		'category' => 'posts'
	),

	'archive_posts' => array (
		'name' => __('Full post or excerpt on home page?', 'toolbox'),
		'desc' => __('You can adjust the excerpt length in the functions file.', 'toolbox'),
		'type' => 'select',
		'options' => array (
			array('full', __('Full post', 'toolbox')),
			array('excerpt', __('Excerpts', 'toolbox'))
		),
		'default' => 'excerpt',
		'category' => 'posts'
	),	
	array (
		'type' => 'section_close'

	),
);

function toolbox_add_admin()
{
	global $themename, $shortname, $options;
	if( $_GET['page'] == basename(__FILE__) ) {
		if(__('Save changes', 'toolbox') == $_REQUEST['action']) {
			foreach($options as $key => $option) {
				
				$id = $shortname.'_'.$key;
				
				if($option['type'] == 'checkbox')
					$value = $_REQUEST[$id]?'on':'off';
				else
					$value = isset($_REQUEST[$id])?stripslashes($_REQUEST[$id]):$option['default'];
				
				update_option($id, $value);
				
			}
			header("Location: themes.php?page=functions.php&saved=true");
			die;
		}
		else if(__('Reset to defaults', 'toolbox') == $_REQUEST['action']) {
			foreach($options as $key => $value)
				delete_option($shortname.'_'.$key);
			header("Location: themes.php?page=functions.php&reset=true");
			die;
		}
		
	}
    add_theme_page($themename.' '.__('Settings', 'toolbox'), $themename.' '.__('Settings', 'toolbox'), 'edit_themes', basename(__FILE__), 'toolbox_admin');

}

function toolbox_admin() {
	global $themename, $shortname, $version, $options;
    $options = $options;	

    if ( $_REQUEST['saved'] ) echo '<div id="message" class="updated fade"><p><strong>'.__('Settings saved', 'toolbox').'</strong></p></div>';
    if ( $_REQUEST['reset'] ) echo '<div id="message" class="updated fade"><p><strong>'.__('Settings reset', 'toolbox').'</strong></p></div>';

?>
<div class="wrap">
<h2><?php echo $themename.' '; _e('Settings', 'toolbox'); ?></h2>
<div id="poststuff" class="metabox-holder">
<div class="stuffbox">
<div class="inside">
<table><tr>
<td style="width:60%;vertical-align:top;">
<p><strong><?php echo $themename; ?> WordPress theme</strong> <?php _e('version', 'toolbox'); ?> <strong><?php echo $version; ?></strong>. <?php printf(__('Visit <a href="%s">theme page</a>', 'toolbox'), 'http://zeaks.org/basic-press-theme/'); ?>. <?php printf(__('View <a href="%s">readme</a>', 'toolbox'), get_template_directory_uri().'/readme.txt'); ?>.</p>
<p>
This theme was created with a <a href="http://themeshaper.com/2010/07/02/toolbox-html5-starter-theme/">Toolbox</a>, theme settings from <a href="http://srinig.com/wordpress/themes/f2/">F2</a> theme. Design by <a href="http://zeaks.org">Zeaks</a>.
</p>
</td>
<td style="width:30%;vertical-align:top;">
<div style="max-width:240px;float:right;">
<p><?php _e('If you enjoy the theme, you can make a donation and support development. Thank you!', 'toolbox'); ?></p>
<div style="text-align:center;">
<form action="https://www.paypal.com/cgi-bin/webscr" method="post">
<input type="hidden" name="cmd" value="_donations">
<input type="hidden" name="business" value="YJCQM2XRQCMYA">
<input type="hidden" name="lc" value="CA">
<input type="hidden" name="item_name" value="Basic Press - Zeaks Blog">
<input type="hidden" name="currency_code" value="CAD">
<input type="hidden" name="bn" value="PP-DonationsBF:btn_donate_LG.gif:NonHosted">
<input type="image" src="https://www.paypalobjects.com/en_US/i/btn/btn_donate_LG.gif" border="0" name="submit" alt="PayPal - The safer, easier way to pay online!">
<img alt="" border="0" src="https://www.paypalobjects.com/en_US/i/scr/pixel.gif" width="1" height="1">
</form>
</div>
</div>
</td>
</tr></table>
</div>
</div>
<form method="post">
<?php
   
	foreach($options as $key => $option) {

		$id = $shortname.'_'.$key;

		$value = get_option($id, $option['default']);
		
		switch ($option['type'] ) {
			case "section": { ?>
<div class="stuffbox">
<h3 id="<?php echo $shortname.'_'.$key; ?>"><?php echo $option['name']; ?></h3>
<div class="inside">
<table class="form-table">
<?php break; }
			case "section_close": { ?>
</table>
</div>
</div>
<?php break; } 
			case 'text': { ?>
<tr<?php if($option['th_class']) echo ' class="'.$option['th_class'].'"'; ?>>
	<th scope="row"><label for="<?php echo $id; ?>"><?php echo $option['name']; ?></label></th>
	<td>
		<input type="text" class="<?php echo $option['class']; ?>"" name="<?php echo $id; ?>" id="<?php echo $id; ?>" value="<?php echo $value; ?>"<?php if($option['class'] == 'colorinput') echo ' size="7"'; elseif($option['class'] == 'pixels') echo ' size="3"'; elseif($option['class'] == 'url') echo ' size="60"'; ?> />
		<?php if($option['class'] == 'pixels') echo "<span style='font-size:12px;'>px</span>"; ?>
		<?php if($option['class'] == 'colorinput') { ?>
		<a class="colorclose" style="cursor:pointer;"><?php _e('Close colorpicker', 'toolbox'); ?></a>
		<div id="colorpicker-<?php echo $key; ?>" class="colorpicker"></div>
		<?php } if($option['desc']) {
			if ($option['class'] == 'url')
				echo "<br />";
			echo "<span class='description' style='font-size:10px'>".$option['desc']."</span>"; 
		} ?>
		
	</td>
</tr>
<?php break; }
			case 'checkbox': { ?>
<tr<?php if($option['th_class']) echo ' class="'.$option['th_class'].'"'; ?>>
	<th scope="row"><label for="<?php echo $id; ?>"><?php echo $option['name']; ?></label></th>
	<td>
		<input type="checkbox" class="<?php echo $option['class']; ?>" name="<?php echo $id; ?>" id="<?php echo $id; ?>"<?php if($value == 'on') echo ' checked="checked"'; ?> />
		<?php if($option['desc']) echo "<span class='description' style='font-size:10px'>".$option['desc']."</span>"; ?>
	</td>
</tr>
<?php break; }
			case 'select': { ?>
<tr<?php if($option['th_class']) echo ' class="'.$option['th_class'].'"'; ?>>
	<th scope="row"><label for="<?php echo $id; ?>"><?php echo $option['name']; ?></label></th>
	<td>
		<select class="<?php echo $option['class']; ?>" name="<?php echo $id; ?>" id="<?php echo $id; ?>">
		<?php foreach ($option['options'] as $sel_opts) {
			echo '<option value="'.$sel_opts[0].'"';
			if($value == $sel_opts[0])
				echo ' selected="selected"';
			echo '>'.$sel_opts[1].'</option>';
		} ?>
		</select>
		<?php if($option['desc']) echo "<span class='description' style='font-size:10px'>".$option['desc']."</span>"; ?>
	</td>
</tr>
<?php break; }
			case 'textarea': { ?>
<tr<?php if($option['th_class']) echo ' class="'.$option['th_class'].'"'; ?>>
	<th scope="row"><label for="<?php echo $id; ?>"><?php echo $option['name']; ?></label></th>
	<td>
		<textarea class="<?php echo $option['class']; ?>" name="<?php echo $id; ?>" id="<?php echo $id; ?>" style="width:100%; height:6em;"><?php echo $value; ?></textarea>
		<?php if($option['desc']) echo "<br /><span class='description' style='font-size:10px'>".$option['desc']."</span>"; ?>
	</td>
</tr>
<?php break; } 
		}
	}
?> 
<input name="action" value="<?php _e('Save changes', 'toolbox'); ?>" class="button-primary" type="submit">
<input name="action" value="<?php _e('Reset to defaults', 'toolbox'); ?>" class="button" type="submit">
</form>
</div>
</div>
<?php
}

add_action('admin_menu', 'toolbox_add_admin');

function toolbox_head()
{
	global $shortname, $options;
	
	foreach($options as $key => $option) 
		$$key = get_option($shortname.'_'.$key, $option['default']);
	if($style) {

		echo "<style type=\"text/css\">\n";
		foreach($style as $selector => $properties) {
			echo $selector." {\n";
			foreach ($properties as $property => $value)
				echo "\t{$property}: {$value};\n";
			echo "}\n";
		}
		echo "</style>\n";
	}
		echo '<link rel="stylesheet" href="'. get_bloginfo('template_url') . '/custom.css" type="text/css" media="screen" />'."\n";
}
add_action('wp_head', 'toolbox_head');
function toolbox_admin_head()
{
	if( $_GET['page'] == basename(__FILE__) ) {
	$template_url = get_bloginfo('template_url');
?>

<?php
}
}

add_action('admin_head', 'toolbox_admin_head');
function toolbox_admin_footer()
{
	if( $_GET['page'] == basename(__FILE__) ) {
?>
<script type="text/javascript">
	jQuery(document).ready(function() {

	if(!jQuery('#toolbox_header_img').is(':checked')) 
		jQuery('.header_img_dependent').hide();
	jQuery('#toolbox_header_img').change(function() {
		if(jQuery('#toolbox_header_img').is(':checked')) 
			jQuery('.header_img_dependent').show();
		else
			jQuery('.header_img_dependent').hide();
	});
	if(!jQuery('#toolbox_hmenu').is(':checked')) 
		jQuery('.hmenu_dependent').hide();
	jQuery('#toolbox_hmenu').change(function() {
		if(jQuery('#toolbox_hmenu').is(':checked')) 
			jQuery('.hmenu_dependent').show();
		else
			jQuery('.hmenu_dependent').hide();
	});
  });
</script>
<?php
	}
}
add_action('admin_footer', 'toolbox_admin_footer');
function toolbox_option($option)
{
	global $shortname, $options;
	return get_option($shortname.'_'.$option, $options[$option]['default']);
}
?>